@@ -18,7 +18,7 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-__version__ = '1.1.3'
+__version__ = '1.1.5'
 __author__ = 'Carlos Perez, Carlos_Perez@darkoperator.com'
 
 __doc__ = """
@@ -257,31 +257,237 @@ def brute_tlds(res, domain, verbose=False, thread_num=None):
     itld = ['arpa']
 
     # Generic TLD
-    gtld = ['co', 'com', 'info', 'net', 'org']
+    gtld = ['aaa', 'aarp', 'abarth', 'abb', 'abbott', 'abbvie', 'abc', 'able',
+            'abogado', 'abudhabi', 'academy', 'accenture', 'accountant',
+            'accountants', 'aco', 'actor', 'ads', 'adult', 'aeg', 'aetna',
+            'afl', 'africa', 'agakhan', 'agency', 'aig', 'airbus', 'airforce',
+            'airtel', 'akdn', 'alfaromeo', 'alibaba', 'alipay', 'allfinanz',
+            'allstate', 'ally', 'alsace', 'alstom', 'amazon', 'americanexpress',
+            'americanfamily', 'amex', 'amfam', 'amica', 'amsterdam',
+            'analytics', 'android', 'anquan', 'anz', 'aol', 'apartments', 'app',
+            'apple', 'aquarelle', 'arab', 'aramco', 'archi', 'army', 'art',
+            'arte', 'asda', 'associates', 'athleta', 'attorney', 'auction',
+            'audi', 'audible', 'audio', 'auspost', 'author', 'auto', 'autos',
+            'avianca', 'aws', 'axa', 'azure', 'baby', 'baidu', 'banamex',
+            'bananarepublic', 'band', 'bank', 'bar', 'barcelona', 'barclaycard',
+            'barclays', 'barefoot', 'bargains', 'baseball', 'basketball',
+            'bauhaus', 'bayern', 'bbc', 'bbt', 'bbva', 'bcg', 'bcn', 'beats',
+            'beauty', 'beer', 'bentley', 'berlin', 'best', 'bestbuy', 'bet',
+            'bharti', 'bible', 'bid', 'bike', 'bing', 'bingo', 'bio', 'black',
+            'blackfriday', 'blockbuster', 'blog', 'bloomberg', 'blue', 'bms',
+            'bmw', 'bnpparibas', 'boats', 'boehringer', 'bofa', 'bom', 'bond',
+            'boo', 'book', 'booking', 'bosch', 'bostik', 'boston', 'bot',
+            'boutique', 'box', 'bradesco', 'bridgestone', 'broadway', 'broker',
+            'brother', 'brussels', 'build', 'builders', 'business', 'buy',
+            'buzz', 'bzh', 'cab', 'cafe', 'cal', 'call', 'calvinklein', 'cam',
+            'camera', 'camp', 'canon', 'capetown', 'capital', 'capitalone',
+            'caravan', 'car', 'cards', 'care', 'career', 'careers', 'cars',
+            'casa', 'case', 'cash', 'casino', 'catering', 'catholic', 'cba',
+            'cbn', 'cbre', 'cbs', 'center', 'ceo', 'cern', 'cfa', 'cfd',
+            'chanel', 'channel', 'charity', 'chase', 'chat', 'cheap', 'chintai',
+            'christmas', 'chrome', 'church', 'cipriani', 'circle', 'cisco',
+            'citadel', 'citic', 'citi', 'city', 'cityeats', 'claims',
+            'cleaning', 'click', 'clinic', 'clinique', 'clothing', 'cloud',
+            'club', 'clubmed', 'coach', 'codes', 'coffee', 'college', 'cologne',
+            'comcast', 'com', 'commbank', 'community', 'company', 'compare',
+            'computer', 'comsec', 'condos', 'construction', 'consulting',
+            'contact', 'contractors', 'cookingchannel', 'cooking', 'cool',
+            'corsica', 'country', 'coupon', 'coupons', 'courses', 'cpa',
+            'creditcard', 'credit', 'creditunion', 'cricket', 'crown', 'crs',
+            'cruise', 'cruises', 'cuisinella', 'cymru', 'cyou', 'dabur', 'dad',
+            'dance', 'data', 'date', 'dating', 'datsun', 'day', 'dclk', 'dds',
+            'deal', 'dealer', 'deals', 'degree', 'delivery', 'dell', 'deloitte',
+            'delta', 'democrat', 'dental', 'dentist', 'desi', 'design', 'dev',
+            'dhl', 'diamonds', 'diet', 'digital', 'direct', 'directory',
+            'discount', 'discover', 'dish', 'diy', 'dnp', 'docs', 'doctor',
+            'dog', 'domains', 'dot', 'download', 'drive', 'dtv', 'dubai',
+            'dunlop', 'dupont', 'durban', 'dvag', 'dvr', 'earth', 'eat', 'eco',
+            'edeka', 'education', 'email', 'emerck', 'energy', 'engineer',
+            'engineering', 'enterprises', 'epson', 'equipment', 'ericsson',
+            'erni', 'esq', 'estate', 'etisalat', 'eurovision', 'eus', 'events',
+            'exchange', 'expert', 'exposed', 'express', 'extraspace', 'fage',
+            'fail', 'fairwinds', 'faith', 'family', 'fan', 'fans', 'farmers',
+            'farm', 'fashion', 'fast', 'fedex', 'feedback', 'ferrari',
+            'ferrero', 'fiat', 'fidelity', 'fido', 'film', 'final', 'finance',
+            'financial', 'fire', 'firestone', 'firmdale', 'fish', 'fishing',
+            'fit', 'fitness', 'flickr', 'flights', 'flir', 'florist', 'flowers',
+            'fly', 'food', 'foodnetwork', 'foo', 'football', 'ford', 'forex',
+            'forsale', 'forum', 'foundation', 'fox', 'free', 'fresenius', 'frl',
+            'frogans', 'frontdoor', 'frontier', 'ftr', 'fujitsu', 'fund', 'fun',
+            'furniture', 'futbol', 'fyi', 'gal', 'gallery', 'gallo', 'gallup',
+            'game', 'games', 'gap', 'garden', 'gay', 'gbiz', 'gdn', 'gea',
+            'gent', 'genting', 'george', 'ggee', 'gift', 'gifts', 'gives',
+            'giving', 'glass', 'gle', 'global', 'globo', 'gmail', 'gmbh', 'gmo',
+            'gmx', 'godaddy', 'gold', 'goldpoint', 'golf', 'goodyear', 'goog',
+            'google', 'goo', 'gop', 'got', 'grainger', 'graphics', 'gratis',
+            'green', 'gripe', 'grocery', 'group', 'guardian', 'gucci', 'guge',
+            'guide', 'guitars', 'guru', 'hair', 'hamburg', 'hangout', 'haus',
+            'hbo', 'hdfcbank', 'hdfc', 'healthcare', 'health', 'help',
+            'helsinki', 'here', 'hermes', 'hgtv', 'hiphop', 'hisamitsu',
+            'hitachi', 'hiv', 'hkt', 'hockey', 'holdings', 'holiday',
+            'homedepot', 'homegoods', 'homesense', 'homes', 'honda', 'horse',
+            'hospital', 'host', 'hosting', 'hoteles', 'hotels', 'hot',
+            'hotmail', 'house', 'how', 'hsbc', 'hughes', 'hyatt', 'hyundai',
+            'ibm', 'icbc', 'ice', 'icu', 'ieee', 'ifm', 'ikano', 'imamat',
+            'imdb', 'immobilien', 'immo', 'inc', 'industries', 'infiniti',
+            'info', 'ing', 'ink', 'institute', 'insurance', 'insure',
+            'international', 'intuit', 'investments', 'ipiranga', 'irish',
+            'ismaili', 'istanbul', 'ist', 'itau', 'itv', 'jaguar', 'java',
+            'jcb', 'jeep', 'jetzt', 'jewelry', 'jio', 'jll', 'jmp', 'jnj',
+            'joburg', 'jot', 'joy', 'jpmorgan', 'jprs', 'juegos', 'juniper',
+            'kaufen', 'kddi', 'kerryhotels', 'kerrylogistics',
+            'kerryproperties', 'kfh', 'kia', 'kids', 'kim', 'kinder', 'kindle',
+            'kitchen', 'kiwi', 'koeln', 'komatsu', 'kosher', 'kpmg', 'kpn',
+            'krd', 'kred', 'kuokgroup', 'kyoto', 'lacaixa', 'lamborghini',
+            'lamer', 'lancaster', 'lancia', 'land', 'landrover', 'lanxess',
+            'lasalle', 'latino', 'lat', 'latrobe', 'law', 'lawyer', 'lds',
+            'lease', 'leclerc', 'lefrak', 'legal', 'lego', 'lexus', 'lgbt',
+            'lidl', 'lifeinsurance', 'life', 'lifestyle', 'lighting', 'like',
+            'lilly', 'limited', 'limo', 'lincoln', 'linde', 'link', 'lipsy',
+            'live', 'living', 'llc', 'llp', 'loan', 'loans', 'locker', 'locus',
+            'lol', 'london', 'lotte', 'lotto', 'love', 'lplfinancial', 'lpl',
+            'ltda', 'ltd', 'lundbeck', 'luxe', 'luxury', 'macys', 'madrid',
+            'maif', 'maison', 'makeup', 'management', 'mango', 'man', 'map',
+            'marketing', 'market', 'markets', 'marriott', 'marshalls',
+            'maserati', 'mattel', 'mba', 'mckinsey', 'media', 'med', 'meet',
+            'melbourne', 'meme', 'memorial', 'men', 'menu', 'merckmsd', 'miami',
+            'microsoft', 'mini', 'mint', 'mit', 'mitsubishi', 'mlb', 'mls',
+            'mma', 'mobile', 'mobi', 'moda', 'moe', 'moi', 'mom', 'monash',
+            'money', 'monster', 'mormon', 'mortgage', 'moscow', 'moto',
+            'motorcycles', 'movie', 'mov', 'msd', 'mtn', 'mtr', 'music',
+            'mutual', 'nab', 'nagoya', 'natura', 'navy', 'nba', 'nec',
+            'netbank', 'netflix', 'net', 'network', 'neustar', 'new', 'news',
+            'nextdirect', 'next', 'nexus', 'nfl', 'ngo', 'nhk', 'nico', 'nike',
+            'nikon', 'ninja', 'nissan', 'nissay', 'nokia', 'northwesternmutual',
+            'norton', 'now', 'nowruz', 'nowtv', 'nra', 'nrw', 'ntt', 'nyc',
+            'obi', 'observer', 'office', 'okinawa', 'olayangroup', 'olayan',
+            'oldnavy', 'ollo', 'omega', 'one', 'ong', 'online', 'onl', 'ooo',
+            'open', 'oracle', 'orange', 'organic', 'org', 'origins', 'osaka',
+            'otsuka', 'ott', 'ovh', 'page', 'panasonic', 'paris', 'pars',
+            'partners', 'parts', 'party', 'passagens', 'pay', 'pccw', 'pet',
+            'pfizer', 'pharmacy', 'phd', 'philips', 'phone', 'photography',
+            'photo', 'photos', 'physio', 'pics', 'pictet', 'pictures', 'pid',
+            'ping', 'pink', 'pin', 'pioneer', 'pizza', 'place', 'play',
+            'playstation', 'plumbing', 'plus', 'pnc', 'pohl', 'poker',
+            'politie', 'porn', 'pramerica', 'praxi', 'press', 'prime', 'prod',
+            'productions', 'prof', 'progressive', 'promo', 'properties',
+            'property', 'protection', 'prudential', 'pru', 'pub', 'pwc', 'qpon',
+            'quebec', 'quest', 'racing', 'radio', 'read', 'realestate',
+            'realtor', 'realty', 'recipes', 'red', 'redstone', 'redumbrella',
+            'rehab', 'reisen', 'reise', 'reit', 'reliance', 'ren', 'rentals',
+            'rent', 'repair', 'report', 'republican', 'restaurant', 'rest',
+            'review', 'reviews', 'rexroth', 'richardli', 'rich', 'ricoh', 'ril',
+            'rio', 'rip', 'rocher', 'rocks', 'rodeo', 'rogers', 'room', 'rsvp',
+            'rugby', 'ruhr', 'run', 'rwe', 'ryukyu', 'saarland', 'safe',
+            'safety', 'sakura', 'sale', 'salon', 'samsclub', 'samsung',
+            'sandvikcoromant', 'sandvik', 'sanofi', 'sap', 'sarl', 'sas',
+            'save', 'saxo', 'sbi', 'sbs', 'sca', 'scb', 'schaeffler', 'schmidt',
+            'scholarships', 'school', 'schule', 'schwarz', 'science', 'scot',
+            'search', 'seat', 'secure', 'security', 'seek', 'select', 'sener',
+            'services', 'seven', 'sew', 'sex', 'sexy', 'sfr', 'shangrila',
+            'sharp', 'shaw', 'shell', 'shia', 'shiksha', 'shoes', 'shopping',
+            'shop', 'shouji', 'show', 'showtime', 'silk', 'sina', 'singles',
+            'site', 'skin', 'ski', 'skype', 'sky', 'sling', 'smart', 'smile',
+            'sncf', 'soccer', 'social', 'softbank', 'software', 'sohu', 'solar',
+            'solutions', 'song', 'sony', 'soy', 'space', 'spa', 'sport', 'spot',
+            'srl', 'stada', 'staples', 'star', 'statebank', 'statefarm',
+            'stcgroup', 'stc', 'stockholm', 'storage', 'store', 'stream',
+            'studio', 'study', 'style', 'sucks', 'supplies', 'supply',
+            'support', 'surf', 'surgery', 'suzuki', 'swatch', 'swiss', 'sydney',
+            'systems', 'tab', 'taipei', 'talk', 'taobao', 'target',
+            'tatamotors', 'tatar', 'tattoo', 'taxi', 'tax', 'tci', 'tdk',
+            'team', 'technology', 'tech', 'temasek', 'tennis', 'teva', 'thd',
+            'theater', 'theatre', 'tiaa', 'tickets', 'tienda', 'tiffany',
+            'tips', 'tires', 'tirol', 'tjmaxx', 'tjx', 'tkmaxx', 'tmall',
+            'today', 'tokyo', 'tools', 'top', 'toray', 'toshiba', 'total',
+            'tours', 'town', 'toyota', 'toys', 'trade', 'trading', 'training',
+            'travelchannel', 'travelersinsurance', 'travelers', 'trust', 'trv',
+            'tube', 'tui', 'tunes', 'tushu', 'tvs', 'ubank', 'ubs', 'unicom',
+            'university', 'uno', 'uol', 'ups', 'vacations', 'vana', 'vanguard',
+            'vegas', 'ventures', 'verisign', 'versicherung', 'vet', 'viajes',
+            'video', 'vig', 'viking', 'villas', 'vin', 'vip', 'virgin', 'visa',
+            'vision', 'viva', 'vivo', 'vlaanderen', 'vodka', 'volkswagen',
+            'volvo', 'vote', 'voting', 'voto', 'voyage', 'vuelos', 'wales',
+            'walmart', 'walter', 'wanggou', 'wang', 'watches', 'watch',
+            'weatherchannel', 'weather', 'webcam', 'weber', 'website',
+            'wedding', 'wed', 'weibo', 'weir', 'whoswho', 'wien', 'wiki',
+            'williamhill', 'windows', 'wine', 'winners', 'win', 'wme',
+            'wolterskluwer', 'woodside', 'works', 'work', 'world', 'wow', 'wtc',
+            'wtf', 'xbox', 'xerox', 'xfinity', 'xihuan', 'xin', 'xn--11b4c3d',
+            'xn--1ck2e1b', 'xn--1qqw23a', 'xn--30rr7y', 'xn--3bst00m',
+            'xn--3ds443g', 'xn--3pxu8k', 'xn--42c2d9a', 'xn--45q11c',
+            'xn--4gbrim', 'xn--55qw42g', 'xn--55qx5d', 'xn--5su34j936bgsg',
+            'xn--5tzm5g', 'xn--6frz82g', 'xn--6qq986b3xl', 'xn--80adxhks',
+            'xn--80aqecdr1a', 'xn--80asehdb', 'xn--80aswg', 'xn--8y0a063a',
+            'xn--9dbq2a', 'xn--9et52u', 'xn--9krt00a', 'xn--b4w605ferd',
+            'xn--bck1b9a5dre4c', 'xn--c1avg', 'xn--c2br7g', 'xn--cck2b3b',
+            'xn--cckwcxetd', 'xn--cg4bki', 'xn--czr694b', 'xn--czrs0t',
+            'xn--czru2d', 'xn--d1acj3b', 'xn--eckvdtc9d', 'xn--efvy88h',
+            'xn--fct429k', 'xn--fhbei', 'xn--fiq228c5hs', 'xn--fiq64b',
+            'xn--fjq720a', 'xn--flw351e', 'xn--fzys8d69uvgm', 'xn--g2xx48c',
+            'xn--gckr3f0f', 'xn--gk3at1e', 'xn--hxt814e', 'xn--i1b6b1a6a2e',
+            'xn--imr513n', 'xn--io0a7i', 'xn--j1aef', 'xn--jlq480n2rg',
+            'xn--jvr189m', 'xn--kcrx77d1x4a', 'xn--kput3i', 'xn--mgba3a3ejt',
+            'xn--mgba7c0bbn0a', 'xn--mgbaakc7dvf', 'xn--mgbab2bd',
+            'xn--mgbca7dzdo', 'xn--mgbi4ecexp', 'xn--mgbt3dhd', 'xn--mk1bu44c',
+            'xn--mxtq1m', 'xn--ngbc5azd', 'xn--ngbe9e0a', 'xn--ngbrx',
+            'xn--nqv7fs00ema', 'xn--nqv7f', 'xn--nyqy26a', 'xn--otu796d',
+            'xn--p1acf', 'xn--pssy2u', 'xn--q9jyb4c', 'xn--qcka1pmc',
+            'xn--rhqv96g', 'xn--rovu88b', 'xn--ses554g', 'xn--t60b56a',
+            'xn--tckwe', 'xn--tiq49xqyj', 'xn--unup4y',
+            'xn--vermgensberater-ctb', 'xn--vermgensberatung-pwb', 'xn--vhquv',
+            'xn--vuq861b', 'xn--w4r85el8fhu5dnra', 'xn--w4rs40l', 'xn--xhq521b',
+            'xn--zfr164b', 'xyz', 'yachts', 'yahoo', 'yamaxun', 'yandex',
+            'yodobashi', 'yoga', 'yokohama', 'youtube', 'you', 'yun', 'zappos',
+            'zara', 'zero', 'zip', 'zone', 'zuerich']
 
     # Generic restricted TLD
-    grtld = ['biz', 'name', 'online', 'pro', 'shop', 'site', 'top', 'xyz', 'cloud']
+    grtld = ['biz', 'name', 'pro']
 
     # Sponsored TLD
-    stld = ['aero', 'app', 'asia', 'cat', 'coop', 'dev', 'edu', 'gov', 'int', 'jobs', 'mil', 'mobi', 'museum', 'post',
-            'tel', 'travel', 'xxx']
+    stld = ['aero', 'asia', 'cat', 'coop', 'edu', 'gov', 'int', 'jobs', 'mil',
+            'museum', 'post', 'tel', 'travel', 'xxx']
 
     # Country Code TLD
-    cctld = ['ac', 'ad', 'ae', 'af', 'ag', 'ai', 'al', 'am', 'an', 'ao', 'aq', 'ar', 'as', 'at', 'au', 'aw', 'ax', 'az',
-             'ba', 'bb', 'bd', 'be', 'bf', 'bg', 'bh', 'bi', 'bj', 'bl', 'bm', 'bn', 'bo', 'bq', 'br', 'bs', 'bt', 'bv',
-             'bw', 'by', 'bz', 'ca', 'cc', 'cd', 'cf', 'cg', 'ch', 'ci', 'ck', 'cl', 'cm', 'cn', 'co', 'cr', 'cu', 'cv',
-             'cw', 'cx', 'cy', 'cz', 'de', 'dj', 'dk', 'dm', 'do', 'dz', 'ec', 'ee', 'eg', 'eh', 'er', 'es', 'et', 'eu',
-             'fi', 'fj', 'fk', 'fm', 'fo', 'fr', 'ga', 'gb', 'gd', 'ge', 'gf', 'gg', 'gh', 'gi', 'gl', 'gm', 'gn', 'gp',
-             'gq', 'gr', 'gs', 'gt', 'gu', 'gw', 'gy', 'hk', 'hm', 'hn', 'hr', 'ht', 'hu', 'id', 'ie', 'il', 'im', 'in',
-             'io', 'iq', 'ir', 'is', 'it', 'je', 'jm', 'jo', 'jp', 'ke', 'kg', 'kh', 'ki', 'km', 'kn', 'kp', 'kr', 'kw',
-             'ky', 'kz', 'la', 'lb', 'lc', 'li', 'lk', 'lr', 'ls', 'lt', 'lu', 'lv', 'ly', 'ma', 'mc', 'md', 'me', 'mf',
-             'mg', 'mh', 'mk', 'ml', 'mm', 'mn', 'mo', 'mp', 'mq', 'mr', 'ms', 'mt', 'mu', 'mv', 'mw', 'mx', 'my', 'mz',
-             'na', 'nc', 'ne', 'nf', 'ng', 'ni', 'nl', 'no', 'np', 'nr', 'nu', 'nz', 'om', 'pa', 'pe', 'pf', 'pg', 'ph',
-             'pk', 'pl', 'pm', 'pn', 'pr', 'ps', 'pt', 'pw', 'py', 'qa', 're', 'ro', 'rs', 'ru', 'rw', 'sa', 'sb', 'sc',
-             'sd', 'se', 'sg', 'sh', 'si', 'sj', 'sk', 'sl', 'sm', 'sn', 'so', 'sr', 'ss', 'st', 'su', 'sv', 'sx', 'sy',
-             'sz', 'tc', 'td', 'tf', 'tg', 'th', 'tj', 'tk', 'tl', 'tm', 'tn', 'to', 'tp', 'tr', 'tt', 'tv', 'tw', 'tz',
-             'ua', 'ug', 'uk', 'um', 'us', 'uy', 'uz', 'va', 'vc', 've', 'vg', 'vi', 'vn', 'vu', 'wf', 'ws', 'yt', 'za',
-             'zm', 'zw']
+    cctld = ['ac', 'ad', 'ae', 'af', 'ag', 'ai', 'al', 'am', 'ao', 'aq', 'ar',
+             'as', 'at', 'au', 'aw', 'ax', 'az', 'ba', 'bb', 'bd', 'be', 'bf',
+             'bg', 'bh', 'bi', 'bj', 'bm', 'bn', 'bo', 'br', 'bs', 'bt', 'bv',
+             'bw', 'by', 'bz', 'ca', 'cc', 'cd', 'cf', 'cg', 'ch', 'ci', 'ck',
+             'cl', 'cm', 'cn', 'co', 'cr', 'cu', 'cv', 'cw', 'cx', 'cy', 'cz',
+             'de', 'dj', 'dk', 'dm', 'do', 'dz', 'ec', 'ee', 'eg', 'er', 'es',
+             'et', 'eu', 'fi', 'fj', 'fk', 'fm', 'fo', 'fr', 'ga', 'gb', 'gd',
+             'ge', 'gf', 'gg', 'gh', 'gi', 'gl', 'gm', 'gn', 'gp', 'gq', 'gr',
+             'gs', 'gt', 'gu', 'gw', 'gy', 'hk', 'hm', 'hn', 'hr', 'ht', 'hu',
+             'id', 'ie', 'il', 'im', 'in', 'io', 'iq', 'ir', 'is', 'it', 'je',
+             'jm', 'jo', 'jp', 'ke', 'kg', 'kh', 'ki', 'km', 'kn', 'kp', 'kr',
+             'kw', 'ky', 'kz', 'la', 'lb', 'lc', 'li', 'lk', 'lr', 'ls', 'lt',
+             'lu', 'lv', 'ly', 'ma', 'mc', 'md', 'me', 'mg', 'mh', 'mk', 'ml',
+             'mm', 'mn', 'mo', 'mp', 'mq', 'mr', 'ms', 'mt', 'mu', 'mv', 'mw',
+             'mx', 'my', 'mz', 'na', 'nc', 'ne', 'nf', 'ng', 'ni', 'nl', 'no',
+             'np', 'nr', 'nu', 'nz', 'om', 'pa', 'pe', 'pf', 'pg', 'ph', 'pk',
+             'pl', 'pm', 'pn', 'pr', 'ps', 'pt', 'pw', 'py', 'qa', 're', 'ro',
+             'rs', 'ru', 'rw', 'sa', 'sb', 'sc', 'sd', 'se', 'sg', 'sh', 'si',
+             'sj', 'sk', 'sl', 'sm', 'sn', 'so', 'sr', 'ss', 'st', 'su', 'sv',
+             'sx', 'sy', 'sz', 'tc', 'td', 'tf', 'tg', 'th', 'tj', 'tk', 'tl',
+             'tm', 'tn', 'to', 'tr', 'tt', 'tv', 'tw', 'tz', 'ua', 'ug', 'uk',
+             'us', 'uy', 'uz', 'va', 'vc', 've', 'vg', 'vi', 'vn', 'vu', 'wf',
+             'ws', 'xn--2scrj9c', 'xn--3e0b707e', 'xn--3hcrj9c', 'xn--45br5cyl',
+             'xn--45brj9c', 'xn--4dbrk0ce', 'xn--54b7fta0cc', 'xn--80ao21a',
+             'xn--90a3ac', 'xn--90ae', 'xn--90ais', 'xn--clchc0ea0b2g2a9gcd',
+             'xn--d1alf', 'xn--e1a4c', 'xn--fiqs8s', 'xn--fiqz9s',
+             'xn--fpcrj9c3d', 'xn--fzc2c9e2c', 'xn--gecrj9c', 'xn--h2breg3eve',
+             'xn--h2brj9c8c', 'xn--h2brj9c', 'xn--j1amh', 'xn--j6w193g',
+             'xn--kprw13d', 'xn--kpry57d', 'xn--l1acc', 'xn--lgbbat1ad8j',
+             'xn--mgb9awbf', 'xn--mgba3a4f16a', 'xn--mgbaam7a8h',
+             'xn--mgbah1a3hjkrd', 'xn--mgbai9azgqp6j', 'xn--mgbayh7gpa',
+             'xn--mgbbh1a71e', 'xn--mgbbh1a', 'xn--mgbc0a9azcg',
+             'xn--mgbcpq6gpa1a', 'xn--mgberp4a5d4ar', 'xn--mgbgu82a',
+             'xn--mgbpl2fh', 'xn--mgbtx2b', 'xn--mgbx4cd0ab', 'xn--mix891f',
+             'xn--node', 'xn--o3cw4h', 'xn--ogbpf8fl', 'xn--p1ai',
+             'xn--pgbs0dh', 'xn--q7ce6a', 'xn--qxa6a', 'xn--qxam',
+             'xn--rvc1e0am3e', 'xn--s9brj9c', 'xn--wgbh1c', 'xn--wgbl6a',
+             'xn--xkc2al3hye2a', 'xn--xkc2dl3a5ee0h', 'xn--y9a3aq',
+             'xn--yfro4i67o', 'xn--ygbi2ammx', 'ye', 'yt', 'za', 'zm', 'zw']
 
     domain_main = domain.split(".")[0]
 
@@ -299,6 +505,8 @@ def brute_tlds(res, domain, verbose=False, thread_num=None):
             print_status(f'Trying: {domain_main}.{cc}')
         for cc, tld in zip(cctld, total_tlds):
             print_status(f'Trying: {domain_main}.{cc}.{tld}')
+
+    found_tlds = []
     try:
         with futures.ThreadPoolExecutor(max_workers=thread_num) as executor:
             future_results = {**{executor.submit(res.get_ip, f'{domain_main}.{tld}'): tld for tld in total_tlds},
@@ -306,19 +514,18 @@ def brute_tlds(res, domain, verbose=False, thread_num=None):
                               **{executor.submit(res.get_ip, f'{domain_main}.{cc}.{tld}'): (cc, tld) for (cc, tld) in
                                  zip(cctld, total_tlds)}}
 
-            brtdata = [future.result() for future in futures.as_completed(future_results)]
-            brtdata = [result for result in brtdata if len(result) > 0]
+            # Display logs as soon as a thread is finished
+            for future in futures.as_completed(future_results):
+                res = future.result()
+                for type_, name_, addr_ in res:
+                    if type_ in ['A', 'AAAA']:
+                        print_good(f"\t {type_} {name_} {addr_}")
+                        found_tlds.append([{"type": type_, "name": name_, "address": addr_}])
+            print_good(f"{len(found_tlds)} Records Found")
 
     except Exception as e:
         print_error(e)
 
-    found_tlds = []
-    for rcd_found in brtdata:
-        for type_, name_, addr_ in rcd_found:
-            if type_ in ['A', 'AAAA']:
-                print_good(f"\t {type_} {name_} {addr_}")
-                found_tlds.append([{"type": type_, "name": name_, "address": addr_}])
-    print_good(f"{len(found_tlds)} Records Found")
     return found_tlds
 
 
@@ -352,29 +559,29 @@ def brute_srv(res, domain, verbose=False, thread_num=None):
 
     try:
         with futures.ThreadPoolExecutor(max_workers=thread_num) as executor:
-            future_results = {executor.submit(res.get_srv, srvtype + domain): srvtype for srvtype in srvrcd}
-            brtdata = [future.result() for future in futures.as_completed(future_results)]
             if verbose:
                 for srvtype in srvrcd:
                     srvtype_domain = srvtype + domain
                     print_status(f"Trying {srvtype_domain}...")
+            future_results = {executor.submit(res.get_srv, srvtype + domain): srvtype for srvtype in srvrcd}
+            # Display logs as soon as a thread is finished
+            for future in futures.as_completed(future_results):
+                res = future.result()
+                for type_, name_, target_, addr_, port_, priority_ in res:
+                    returned_records.append({"type": type_,
+                                             "name": name_,
+                                             "target": target_,
+                                             "address": addr_,
+                                             "port": port_})
+                    print_good(f"\t {type_} {name_} {target_} {addr_} {port_}")
     except Exception as e:
         print_error(e)
 
-    if brtdata:
-        for rcd_found in brtdata:
-            for type_, name_, target_, addr_, port_, priority_ in rcd_found:
-                returned_records.append({"type": type_,
-                                         "name": name_,
-                                         "target": target_,
-                                         "address": addr_,
-                                         "port": port_})
-                print_good(f"\t {type_} {name_} {target_} {addr_} {port_}")
+    if len(returned_records) > 0:
+        print_good(f"{len(returned_records)} Records Found")
     else:
         print_error(f"No SRV Records Found for {domain}")
 
-    print_good(f"{len(returned_records)} Records Found")
-
     return returned_records
 
 
@@ -399,25 +606,23 @@ def brute_reverse(res, ip_list, verbose=False, thread_num=None):
         for ip_group in [ip_range[j:j + ip_group_size] for j in range(0, len(ip_range), ip_group_size)]:
 
             try:
-                with futures.ThreadPoolExecutor(max_workers=thread_num) as executor:
-                    future_results = {executor.submit(res.get_ptr, str(ip_list[i][x])): x for x in ip_group}
-                    brtdata = [future.result() for future in futures.as_completed(future_results)]
-                    # Filter out results that are None
-                    brtdata = [result for result in brtdata if result]
-
                 if verbose:
                     for x in ip_group:
                         ipaddress = str(ip_list[x])
                         print_status(f"Trying {ipaddress}")
 
+                with futures.ThreadPoolExecutor(max_workers=thread_num) as executor:
+                    future_results = {executor.submit(res.get_ptr, str(ip_list[i][x])): x for x in ip_group}
+                    # Display logs as soon as a thread is finished
+                    for future in futures.as_completed(future_results):
+                        res_ = future.result()
+                        for type_, name_, addr_ in res_:
+                            returned_records.append([{'type': type_, 'name': name_, 'address': addr_}])
+                            print_good(f"\t {type_} {name_} {addr_}")
+
             except Exception as e:
                 print_error(e)
 
-            for rcd_found in brtdata:
-                for type_, name_, addr_ in rcd_found:
-                    returned_records.append([{'type': type_, 'name': name_, 'address': addr_}])
-                    print_good(f"\t {type_} {name_} {addr_}")
-
     print_good(f"{len(returned_records)} Records Found")
     return returned_records
 
@@ -449,32 +654,30 @@ def brute_domain(res, dictfile, dom, filter_=None, verbose=False, ignore_wildcar
                     print_status(f"Trying {target}")
         with futures.ThreadPoolExecutor(max_workers=thread_num) as executor:
             future_results = {executor.submit(res.get_ip, target): target for target in targets}
-            brtdata = [future.result() for future in futures.as_completed(future_results)]
-
-    # Process the output of the threads.
-    for rcd_found in brtdata:
-        for type_, name_, address_or_target_ in rcd_found:
-            print_and_append = False
-            found_dict = {"type": type_, "name": name_}
-            if type_ in ['A', 'AAAA']:
-                # Filter Records if filtering was enabled
-                if filter_:
-                    if wildcard_set and address_or_target_ not in wildcard_set:
+            # Display logs as soon as a thread is finished
+            for future in futures.as_completed(future_results):
+                res = future.result()
+                for type_, name_, address_or_target_ in res:
+                    print_and_append = False
+                    found_dict = {"type": type_, "name": name_}
+                    if type_ in ['A', 'AAAA']:
+                        # Filter Records if filtering was enabled
+                        if filter_:
+                            if not wildcard_set or address_or_target_ not in wildcard_set:
+                                print_and_append = True
+                                found_dict["address"] = address_or_target_
+                        else:
+                            print_and_append = True
+                            found_dict["address"] = address_or_target_
+                    elif type_ == 'CNAME':
                         print_and_append = True
-                        found_dict["address"] = address_or_target_
-                else:
-                    print_and_append = True
-                    found_dict["address"] = address_or_target_
-            elif type_ == 'CNAME':
-                print_and_append = True
-                found_dict["target"] = address_or_target_
+                        found_dict["target"] = address_or_target_
 
-            if print_and_append:
-                print_good(f"\t {type_} {name_} {address_or_target_}")
-                found_hosts.append(found_dict)
+                    if print_and_append:
+                        print_good(f"\t {type_} {name_} {address_or_target_}")
+                        found_hosts.append(found_dict)
 
-    # Clear Global variable
-    brtdata = []
+                brtdata.append(res)
 
     print_good(f"{len(found_hosts)} Records Found")
     return found_hosts
@@ -842,7 +1045,7 @@ def dns_sec_check(domain, res):
     Check if a zone is configured for DNSSEC and if so if NSEC or NSEC3 is used.
     """
     try:
-        answer = res.resolve(domain, 'DNSKEY')
+        answer = res.resolve(domain, 'DNSKEY', res._res.nameservers[0])
         print_status("DNSSEC is configured for {0}".format(domain))
         nsectype = get_nsec_type(domain, res)
         print_status("DNSKEYs:")
@@ -944,7 +1147,7 @@ def general_enum(res, domain, do_axfr, do_bing, do_yandex, do_spf, do_whois, do_
             if len(returned_records) == 0:
                 from_zt = True
 
-    # If a Zone Trasfer was possible there is no need to enumerate the rest
+    # If a Zone Transfer was possible there is no need to enumerate the rest
     if from_zt is None:
 
         # Check if DNSSEC is configured
